@@ -6,9 +6,9 @@ Type annotations for emr-containers service type definitions.
 Usage::
 
     ```python
-    from mypy_boto3_emr_containers.type_defs import CancelJobRunRequestTypeDef
+    from mypy_boto3_emr_containers.type_defs import CancelJobRunRequestRequestTypeDef
 
-    data: CancelJobRunRequestTypeDef = {...}
+    data: CancelJobRunRequestRequestTypeDef = {...}
     ```
 """
 import sys
@@ -34,61 +34,61 @@ else:
 
 
 __all__ = (
-    "CancelJobRunRequestTypeDef",
-    "CancelJobRunResponseResponseTypeDef",
+    "CancelJobRunRequestRequestTypeDef",
+    "CancelJobRunResponseTypeDef",
     "CloudWatchMonitoringConfigurationTypeDef",
     "ConfigurationOverridesTypeDef",
     "ConfigurationTypeDef",
     "ContainerInfoTypeDef",
     "ContainerProviderTypeDef",
-    "CreateManagedEndpointRequestTypeDef",
-    "CreateManagedEndpointResponseResponseTypeDef",
-    "CreateVirtualClusterRequestTypeDef",
-    "CreateVirtualClusterResponseResponseTypeDef",
-    "DeleteManagedEndpointRequestTypeDef",
-    "DeleteManagedEndpointResponseResponseTypeDef",
-    "DeleteVirtualClusterRequestTypeDef",
-    "DeleteVirtualClusterResponseResponseTypeDef",
-    "DescribeJobRunRequestTypeDef",
-    "DescribeJobRunResponseResponseTypeDef",
-    "DescribeManagedEndpointRequestTypeDef",
-    "DescribeManagedEndpointResponseResponseTypeDef",
-    "DescribeVirtualClusterRequestTypeDef",
-    "DescribeVirtualClusterResponseResponseTypeDef",
+    "CreateManagedEndpointRequestRequestTypeDef",
+    "CreateManagedEndpointResponseTypeDef",
+    "CreateVirtualClusterRequestRequestTypeDef",
+    "CreateVirtualClusterResponseTypeDef",
+    "DeleteManagedEndpointRequestRequestTypeDef",
+    "DeleteManagedEndpointResponseTypeDef",
+    "DeleteVirtualClusterRequestRequestTypeDef",
+    "DeleteVirtualClusterResponseTypeDef",
+    "DescribeJobRunRequestRequestTypeDef",
+    "DescribeJobRunResponseTypeDef",
+    "DescribeManagedEndpointRequestRequestTypeDef",
+    "DescribeManagedEndpointResponseTypeDef",
+    "DescribeVirtualClusterRequestRequestTypeDef",
+    "DescribeVirtualClusterResponseTypeDef",
     "EksInfoTypeDef",
     "EndpointTypeDef",
     "JobDriverTypeDef",
     "JobRunTypeDef",
-    "ListJobRunsRequestTypeDef",
-    "ListJobRunsResponseResponseTypeDef",
-    "ListManagedEndpointsRequestTypeDef",
-    "ListManagedEndpointsResponseResponseTypeDef",
-    "ListTagsForResourceRequestTypeDef",
-    "ListTagsForResourceResponseResponseTypeDef",
-    "ListVirtualClustersRequestTypeDef",
-    "ListVirtualClustersResponseResponseTypeDef",
+    "ListJobRunsRequestRequestTypeDef",
+    "ListJobRunsResponseTypeDef",
+    "ListManagedEndpointsRequestRequestTypeDef",
+    "ListManagedEndpointsResponseTypeDef",
+    "ListTagsForResourceRequestRequestTypeDef",
+    "ListTagsForResourceResponseTypeDef",
+    "ListVirtualClustersRequestRequestTypeDef",
+    "ListVirtualClustersResponseTypeDef",
     "MonitoringConfigurationTypeDef",
     "PaginatorConfigTypeDef",
     "ResponseMetadataTypeDef",
     "S3MonitoringConfigurationTypeDef",
     "SparkSubmitJobDriverTypeDef",
-    "StartJobRunRequestTypeDef",
-    "StartJobRunResponseResponseTypeDef",
-    "TagResourceRequestTypeDef",
-    "UntagResourceRequestTypeDef",
+    "StartJobRunRequestRequestTypeDef",
+    "StartJobRunResponseTypeDef",
+    "TagResourceRequestRequestTypeDef",
+    "UntagResourceRequestRequestTypeDef",
     "VirtualClusterTypeDef",
 )
 
-CancelJobRunRequestTypeDef = TypedDict(
-    "CancelJobRunRequestTypeDef",
+CancelJobRunRequestRequestTypeDef = TypedDict(
+    "CancelJobRunRequestRequestTypeDef",
     {
         "id": str,
         "virtualClusterId": str,
     },
 )
 
-CancelJobRunResponseResponseTypeDef = TypedDict(
-    "CancelJobRunResponseResponseTypeDef",
+CancelJobRunResponseTypeDef = TypedDict(
+    "CancelJobRunResponseTypeDef",
     {
         "id": str,
         "virtualClusterId": str,
@@ -177,8 +177,8 @@ class ContainerProviderTypeDef(
     pass
 
 
-_RequiredCreateManagedEndpointRequestTypeDef = TypedDict(
-    "_RequiredCreateManagedEndpointRequestTypeDef",
+_RequiredCreateManagedEndpointRequestRequestTypeDef = TypedDict(
+    "_RequiredCreateManagedEndpointRequestRequestTypeDef",
     {
         "name": str,
         "virtualClusterId": str,
@@ -189,8 +189,8 @@ _RequiredCreateManagedEndpointRequestTypeDef = TypedDict(
         "clientToken": str,
     },
 )
-_OptionalCreateManagedEndpointRequestTypeDef = TypedDict(
-    "_OptionalCreateManagedEndpointRequestTypeDef",
+_OptionalCreateManagedEndpointRequestRequestTypeDef = TypedDict(
+    "_OptionalCreateManagedEndpointRequestRequestTypeDef",
     {
         "configurationOverrides": "ConfigurationOverridesTypeDef",
         "tags": Dict[str, str],
@@ -199,14 +199,15 @@ _OptionalCreateManagedEndpointRequestTypeDef = TypedDict(
 )
 
 
-class CreateManagedEndpointRequestTypeDef(
-    _RequiredCreateManagedEndpointRequestTypeDef, _OptionalCreateManagedEndpointRequestTypeDef
+class CreateManagedEndpointRequestRequestTypeDef(
+    _RequiredCreateManagedEndpointRequestRequestTypeDef,
+    _OptionalCreateManagedEndpointRequestRequestTypeDef,
 ):
     pass
 
 
-CreateManagedEndpointResponseResponseTypeDef = TypedDict(
-    "CreateManagedEndpointResponseResponseTypeDef",
+CreateManagedEndpointResponseTypeDef = TypedDict(
+    "CreateManagedEndpointResponseTypeDef",
     {
         "id": str,
         "name": str,
@@ -216,16 +217,16 @@ CreateManagedEndpointResponseResponseTypeDef = TypedDict(
     },
 )
 
-_RequiredCreateVirtualClusterRequestTypeDef = TypedDict(
-    "_RequiredCreateVirtualClusterRequestTypeDef",
+_RequiredCreateVirtualClusterRequestRequestTypeDef = TypedDict(
+    "_RequiredCreateVirtualClusterRequestRequestTypeDef",
     {
         "name": str,
         "containerProvider": "ContainerProviderTypeDef",
         "clientToken": str,
     },
 )
-_OptionalCreateVirtualClusterRequestTypeDef = TypedDict(
-    "_OptionalCreateVirtualClusterRequestTypeDef",
+_OptionalCreateVirtualClusterRequestRequestTypeDef = TypedDict(
+    "_OptionalCreateVirtualClusterRequestRequestTypeDef",
     {
         "tags": Dict[str, str],
     },
@@ -233,14 +234,15 @@ _OptionalCreateVirtualClusterRequestTypeDef = TypedDict(
 )
 
 
-class CreateVirtualClusterRequestTypeDef(
-    _RequiredCreateVirtualClusterRequestTypeDef, _OptionalCreateVirtualClusterRequestTypeDef
+class CreateVirtualClusterRequestRequestTypeDef(
+    _RequiredCreateVirtualClusterRequestRequestTypeDef,
+    _OptionalCreateVirtualClusterRequestRequestTypeDef,
 ):
     pass
 
 
-CreateVirtualClusterResponseResponseTypeDef = TypedDict(
-    "CreateVirtualClusterResponseResponseTypeDef",
+CreateVirtualClusterResponseTypeDef = TypedDict(
+    "CreateVirtualClusterResponseTypeDef",
     {
         "id": str,
         "name": str,
@@ -249,16 +251,16 @@ CreateVirtualClusterResponseResponseTypeDef = TypedDict(
     },
 )
 
-DeleteManagedEndpointRequestTypeDef = TypedDict(
-    "DeleteManagedEndpointRequestTypeDef",
+DeleteManagedEndpointRequestRequestTypeDef = TypedDict(
+    "DeleteManagedEndpointRequestRequestTypeDef",
     {
         "id": str,
         "virtualClusterId": str,
     },
 )
 
-DeleteManagedEndpointResponseResponseTypeDef = TypedDict(
-    "DeleteManagedEndpointResponseResponseTypeDef",
+DeleteManagedEndpointResponseTypeDef = TypedDict(
+    "DeleteManagedEndpointResponseTypeDef",
     {
         "id": str,
         "virtualClusterId": str,
@@ -266,62 +268,62 @@ DeleteManagedEndpointResponseResponseTypeDef = TypedDict(
     },
 )
 
-DeleteVirtualClusterRequestTypeDef = TypedDict(
-    "DeleteVirtualClusterRequestTypeDef",
+DeleteVirtualClusterRequestRequestTypeDef = TypedDict(
+    "DeleteVirtualClusterRequestRequestTypeDef",
     {
         "id": str,
     },
 )
 
-DeleteVirtualClusterResponseResponseTypeDef = TypedDict(
-    "DeleteVirtualClusterResponseResponseTypeDef",
+DeleteVirtualClusterResponseTypeDef = TypedDict(
+    "DeleteVirtualClusterResponseTypeDef",
     {
         "id": str,
         "ResponseMetadata": "ResponseMetadataTypeDef",
     },
 )
 
-DescribeJobRunRequestTypeDef = TypedDict(
-    "DescribeJobRunRequestTypeDef",
+DescribeJobRunRequestRequestTypeDef = TypedDict(
+    "DescribeJobRunRequestRequestTypeDef",
     {
         "id": str,
         "virtualClusterId": str,
     },
 )
 
-DescribeJobRunResponseResponseTypeDef = TypedDict(
-    "DescribeJobRunResponseResponseTypeDef",
+DescribeJobRunResponseTypeDef = TypedDict(
+    "DescribeJobRunResponseTypeDef",
     {
         "jobRun": "JobRunTypeDef",
         "ResponseMetadata": "ResponseMetadataTypeDef",
     },
 )
 
-DescribeManagedEndpointRequestTypeDef = TypedDict(
-    "DescribeManagedEndpointRequestTypeDef",
+DescribeManagedEndpointRequestRequestTypeDef = TypedDict(
+    "DescribeManagedEndpointRequestRequestTypeDef",
     {
         "id": str,
         "virtualClusterId": str,
     },
 )
 
-DescribeManagedEndpointResponseResponseTypeDef = TypedDict(
-    "DescribeManagedEndpointResponseResponseTypeDef",
+DescribeManagedEndpointResponseTypeDef = TypedDict(
+    "DescribeManagedEndpointResponseTypeDef",
     {
         "endpoint": "EndpointTypeDef",
         "ResponseMetadata": "ResponseMetadataTypeDef",
     },
 )
 
-DescribeVirtualClusterRequestTypeDef = TypedDict(
-    "DescribeVirtualClusterRequestTypeDef",
+DescribeVirtualClusterRequestRequestTypeDef = TypedDict(
+    "DescribeVirtualClusterRequestRequestTypeDef",
     {
         "id": str,
     },
 )
 
-DescribeVirtualClusterResponseResponseTypeDef = TypedDict(
-    "DescribeVirtualClusterResponseResponseTypeDef",
+DescribeVirtualClusterResponseTypeDef = TypedDict(
+    "DescribeVirtualClusterResponseTypeDef",
     {
         "virtualCluster": "VirtualClusterTypeDef",
         "ResponseMetadata": "ResponseMetadataTypeDef",
@@ -389,14 +391,14 @@ JobRunTypeDef = TypedDict(
     total=False,
 )
 
-_RequiredListJobRunsRequestTypeDef = TypedDict(
-    "_RequiredListJobRunsRequestTypeDef",
+_RequiredListJobRunsRequestRequestTypeDef = TypedDict(
+    "_RequiredListJobRunsRequestRequestTypeDef",
     {
         "virtualClusterId": str,
     },
 )
-_OptionalListJobRunsRequestTypeDef = TypedDict(
-    "_OptionalListJobRunsRequestTypeDef",
+_OptionalListJobRunsRequestRequestTypeDef = TypedDict(
+    "_OptionalListJobRunsRequestRequestTypeDef",
     {
         "createdBefore": Union[datetime, str],
         "createdAfter": Union[datetime, str],
@@ -409,14 +411,14 @@ _OptionalListJobRunsRequestTypeDef = TypedDict(
 )
 
 
-class ListJobRunsRequestTypeDef(
-    _RequiredListJobRunsRequestTypeDef, _OptionalListJobRunsRequestTypeDef
+class ListJobRunsRequestRequestTypeDef(
+    _RequiredListJobRunsRequestRequestTypeDef, _OptionalListJobRunsRequestRequestTypeDef
 ):
     pass
 
 
-ListJobRunsResponseResponseTypeDef = TypedDict(
-    "ListJobRunsResponseResponseTypeDef",
+ListJobRunsResponseTypeDef = TypedDict(
+    "ListJobRunsResponseTypeDef",
     {
         "jobRuns": List["JobRunTypeDef"],
         "nextToken": str,
@@ -424,14 +426,14 @@ ListJobRunsResponseResponseTypeDef = TypedDict(
     },
 )
 
-_RequiredListManagedEndpointsRequestTypeDef = TypedDict(
-    "_RequiredListManagedEndpointsRequestTypeDef",
+_RequiredListManagedEndpointsRequestRequestTypeDef = TypedDict(
+    "_RequiredListManagedEndpointsRequestRequestTypeDef",
     {
         "virtualClusterId": str,
     },
 )
-_OptionalListManagedEndpointsRequestTypeDef = TypedDict(
-    "_OptionalListManagedEndpointsRequestTypeDef",
+_OptionalListManagedEndpointsRequestRequestTypeDef = TypedDict(
+    "_OptionalListManagedEndpointsRequestRequestTypeDef",
     {
         "createdBefore": Union[datetime, str],
         "createdAfter": Union[datetime, str],
@@ -444,14 +446,15 @@ _OptionalListManagedEndpointsRequestTypeDef = TypedDict(
 )
 
 
-class ListManagedEndpointsRequestTypeDef(
-    _RequiredListManagedEndpointsRequestTypeDef, _OptionalListManagedEndpointsRequestTypeDef
+class ListManagedEndpointsRequestRequestTypeDef(
+    _RequiredListManagedEndpointsRequestRequestTypeDef,
+    _OptionalListManagedEndpointsRequestRequestTypeDef,
 ):
     pass
 
 
-ListManagedEndpointsResponseResponseTypeDef = TypedDict(
-    "ListManagedEndpointsResponseResponseTypeDef",
+ListManagedEndpointsResponseTypeDef = TypedDict(
+    "ListManagedEndpointsResponseTypeDef",
     {
         "endpoints": List["EndpointTypeDef"],
         "nextToken": str,
@@ -459,23 +462,23 @@ ListManagedEndpointsResponseResponseTypeDef = TypedDict(
     },
 )
 
-ListTagsForResourceRequestTypeDef = TypedDict(
-    "ListTagsForResourceRequestTypeDef",
+ListTagsForResourceRequestRequestTypeDef = TypedDict(
+    "ListTagsForResourceRequestRequestTypeDef",
     {
         "resourceArn": str,
     },
 )
 
-ListTagsForResourceResponseResponseTypeDef = TypedDict(
-    "ListTagsForResourceResponseResponseTypeDef",
+ListTagsForResourceResponseTypeDef = TypedDict(
+    "ListTagsForResourceResponseTypeDef",
     {
         "tags": Dict[str, str],
         "ResponseMetadata": "ResponseMetadataTypeDef",
     },
 )
 
-ListVirtualClustersRequestTypeDef = TypedDict(
-    "ListVirtualClustersRequestTypeDef",
+ListVirtualClustersRequestRequestTypeDef = TypedDict(
+    "ListVirtualClustersRequestRequestTypeDef",
     {
         "containerProviderId": str,
         "containerProviderType": Literal["EKS"],
@@ -488,8 +491,8 @@ ListVirtualClustersRequestTypeDef = TypedDict(
     total=False,
 )
 
-ListVirtualClustersResponseResponseTypeDef = TypedDict(
-    "ListVirtualClustersResponseResponseTypeDef",
+ListVirtualClustersResponseTypeDef = TypedDict(
+    "ListVirtualClustersResponseTypeDef",
     {
         "virtualClusters": List["VirtualClusterTypeDef"],
         "nextToken": str,
@@ -557,8 +560,8 @@ class SparkSubmitJobDriverTypeDef(
     pass
 
 
-_RequiredStartJobRunRequestTypeDef = TypedDict(
-    "_RequiredStartJobRunRequestTypeDef",
+_RequiredStartJobRunRequestRequestTypeDef = TypedDict(
+    "_RequiredStartJobRunRequestRequestTypeDef",
     {
         "virtualClusterId": str,
         "clientToken": str,
@@ -567,8 +570,8 @@ _RequiredStartJobRunRequestTypeDef = TypedDict(
         "jobDriver": "JobDriverTypeDef",
     },
 )
-_OptionalStartJobRunRequestTypeDef = TypedDict(
-    "_OptionalStartJobRunRequestTypeDef",
+_OptionalStartJobRunRequestRequestTypeDef = TypedDict(
+    "_OptionalStartJobRunRequestRequestTypeDef",
     {
         "name": str,
         "configurationOverrides": "ConfigurationOverridesTypeDef",
@@ -578,14 +581,14 @@ _OptionalStartJobRunRequestTypeDef = TypedDict(
 )
 
 
-class StartJobRunRequestTypeDef(
-    _RequiredStartJobRunRequestTypeDef, _OptionalStartJobRunRequestTypeDef
+class StartJobRunRequestRequestTypeDef(
+    _RequiredStartJobRunRequestRequestTypeDef, _OptionalStartJobRunRequestRequestTypeDef
 ):
     pass
 
 
-StartJobRunResponseResponseTypeDef = TypedDict(
-    "StartJobRunResponseResponseTypeDef",
+StartJobRunResponseTypeDef = TypedDict(
+    "StartJobRunResponseTypeDef",
     {
         "id": str,
         "name": str,
@@ -595,16 +598,16 @@ StartJobRunResponseResponseTypeDef = TypedDict(
     },
 )
 
-TagResourceRequestTypeDef = TypedDict(
-    "TagResourceRequestTypeDef",
+TagResourceRequestRequestTypeDef = TypedDict(
+    "TagResourceRequestRequestTypeDef",
     {
         "resourceArn": str,
         "tags": Dict[str, str],
     },
 )
 
-UntagResourceRequestTypeDef = TypedDict(
-    "UntagResourceRequestTypeDef",
+UntagResourceRequestRequestTypeDef = TypedDict(
+    "UntagResourceRequestRequestTypeDef",
     {
         "resourceArn": str,
         "tagKeys": List[str],
